# Copyright (C) 2019-2025 Intel Corporation
#
# SPDX-License-Identifier: MIT

import warnings
from functools import wraps


def deprecated(deprecated_version: str, removed_version: str):
    """Class decorator that marks a class as deprecated."""

    def decorator(cls):
        original_init = cls.__init__

        @wraps(original_init)
        def new_init(self, *args, **kwargs):
            warnings.warn(
                f"The {cls.__name__} class will be deprecated in version {deprecated_version} "
                f"and will be removed in version {removed_version}.",
                DeprecationWarning,
                stacklevel=2,
            )
            original_init(self, *args, **kwargs)

        cls.__init__ = new_init
        return cls

    return decorator



# Copyright (C) 2025 Intel Corporation
#
# SPDX-License-Identifier: MIT

import numpy as np


def normalize_points(positions: list[float]) -> list[float]:
    """
    Normalize a set of keypoints to fit within a unit bounding box [0, 1] x [0, 1],
    maintaining the aspect ratio.

    Parameters:
        keypoints (list[float]): A list of point positions in the format [x1, y1, x2, y2, ..., xn, yn].

    Returns:
        list[float]: Normalized keypoints within the unit bounding box, preserving aspect ratio.
    """
    # Convert keypoints to a NumPy array for easier manipulation
    positions = np.array(positions, dtype=float).reshape(-1, 2)

    # Find the minimum and maximum values for x and y
    min = positions.min(axis=0)
    max = positions.max(axis=0)

    # Compute the width and height of the bounding box
    size = max - min

    # Handle edge case where all keypoints are the same (zero width or height)
    size[np.where(size == 0)] = 1e-6

    # Determine the scaling factor to maintain aspect ratio
    scale = size.max()

    # Normalize the keypoints to fit within [0, 1] x [0, 1], preserving aspect ratio
    normalized_positions = (positions - min) / scale

    return list(map(float, normalized_positions.flatten()))



# Copyright (C) 2019-2022 Intel Corporation
#
# SPDX-License-Identifier: MIT

# pylint: disable=redefined-builtin

from . import (
    compare,
    convert,
    detect_format,
    download,
    explain,
    explore,
    filter,
    generate,
    info,
    merge,
    patch,
    prune,
    stats,
    transform,
    validate,
)
from .require_project import get_project_commands

__all__ = [
    "get_non_project_commands",
    "get_project_commands",
]

deprecated = "[DEPRECATED, will be removed in 1.12]"


def get_non_project_commands():
    return [
        ("convert", convert, "Convert dataset between formats"),
        ("detect", detect_format, "Detect the format of a dataset"),
        ("compare", compare, "Compare datasets"),
        ("dinfo", info, "Print dataset info"),
        ("download", download, "Download a publicly available dataset"),
        ("explain", explain, f"{deprecated} Run Explainable AI algorithm for model"),
        ("explore", explore, f"{deprecated} Explore similar datasetitems of query"),
        ("filter", filter, "Filter dataset items"),
        ("generate", generate, f"{deprecated} Generate synthetic dataset"),
        ("merge", merge, "Merge datasets"),
        ("patch", patch, "Update dataset from another one"),
        ("prune", prune, f"{deprecated} Prune dataset"),
        ("stats", stats, "Compute dataset statistics"),
        ("transform", transform, "Modify dataset items"),
        ("validate", validate, "Validate dataset"),
    ]



# Copyright (C) 2023 Intel Corporation
#
# SPDX-License-Identifier: MIT

from . import modification, versioning

deprecated = "[DEPRECATED, will be removed in 1.12]"


def get_project_commands():
    return [
        ("Project modification:", None, deprecated),
        ("add", modification.add, f"{deprecated} Add dataset"),
        ("create", modification.create, f"{deprecated} Create empty project"),
        ("export", modification.export, f"{deprecated} Export dataset in some format"),
        ("import", modification.import_, f"{deprecated} Import dataset"),
        ("remove", modification.remove, f"{deprecated} Remove dataset"),
        ("", None, ""),
        ("Project versioning:", None, deprecated),
        ("checkout", versioning.checkout, f"{deprecated} Switch to another branch or revision"),
        ("commit", versioning.commit, f"{deprecated} Commit changes in tracked files"),
        ("log", versioning.log, f"{deprecated} List history"),
        ("info", versioning.info, f"{deprecated} Print project information"),
        ("status", versioning.status, f"{deprecated} Display current branch and revision status"),
    ]
